import React, { useState, useEffect, useRef, useMemo } from 'react';

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

var useScrollAware = function (ref) {
    var _a = useState(0), scrollTop = _a[0], setScrollTop = _a[1];
    var onScroll = function (e) {
        requestAnimationFrame(function () {
            setScrollTop(e.target.scrollTop);
        });
    };
    useEffect(function () {
        var container = ref.current;
        container.addEventListener("scroll", onScroll);
        return function () {
            container.removeEventListener("scroll", onScroll);
        };
    }, []);
    return scrollTop;
};

var VirtualScroll = function (_a) {
    var RowComponent = _a.RowComponent, height = _a.height, itemHeight = _a.itemHeight, itemCount = _a.itemCount, renderAhread = _a.renderAhread, data = _a.data, loadMore = _a.loadMore;
    var ref = useRef(null);
    var scrollTop = useScrollAware(ref);
    var startIndex = Math.floor(scrollTop / itemHeight) - renderAhread;
    startIndex = Math.max(startIndex, 0);
    var totalHeight = itemCount * itemHeight;
    var offsetY = startIndex * itemHeight;
    var visibleItemCount = Math.floor(height / itemHeight);
    var size = startIndex + visibleItemCount + 2 * renderAhread;
    useEffect(function () {
        if (scrollTop >= data.length * itemHeight - height) {
            loadMore();
        }
    }, [data, itemHeight, scrollTop]);
    var visibleChildren = useMemo(function () {
        var result = data
            .slice(startIndex, size)
            .map(function (item) { return React.createElement(RowComponent, __assign({ key: item.key }, item)); });
        return result;
    }, [startIndex, data]);
    return (React.createElement("div", { ref: ref, className: "virtual-scroll", style: {
            height: height + "px",
            overflow: "auto",
        } },
        React.createElement("div", { style: {
                willChange: "transform",
                height: totalHeight + "px",
            } },
            React.createElement("div", { style: {
                    willChange: "transform",
                    transform: "translateY(" + offsetY + "px)",
                } }, visibleChildren))));
};
VirtualScroll.defaultProps = {
    renderAhread: 20,
    loadMore: function () { },
};

export { VirtualScroll as default };
//# sourceMappingURL=index.esm.js.map
